@@ -15,9 +15,11 @@
 package org.pdfsam.guiclient.commons.business;
 
 import java.io.File;
-import java.io.FileInputStream;
+import java.util.HashMap;
+import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Map;
 
 import javax.swing.JFileChooser;
 import javax.swing.JOptionPane;
@@ -26,10 +28,13 @@ import org.apache.log4j.Logger;
 import org.pdfsam.guiclient.commons.panels.JPdfSelectionPanel;
 import org.pdfsam.guiclient.configuration.Configuration;
 import org.pdfsam.guiclient.dto.PdfSelectionTableItem;
+import org.pdfsam.guiclient.utils.EncryptionUtility;
 import org.pdfsam.guiclient.utils.filters.PdfFilter;
 import org.pdfsam.i18n.GettextResource;
 
+import com.lowagie.text.pdf.PdfName;
 import com.lowagie.text.pdf.PdfReader;
+import com.lowagie.text.pdf.PdfWriter;
 import com.lowagie.text.pdf.RandomAccessFileOrArray;
 /**
  * Business class whose job is to load pdf file to PdfSelectionTableItem
@@ -40,29 +45,24 @@ public class PdfLoader {
 
 	private static final Logger log = Logger.getLogger(PdfLoader.class.getPackage().getName());
 	
-    //threshold to low priority addThread 
-    private static long LOW_PRIORITY_SIZE = 5*1024*1024; //5MB
-    
+	/*used to find the document data*/
+	private static String TITLE = PdfName.decodeName(PdfName.TITLE.toString());
+	private static String PRODUCER = PdfName.decodeName(PdfName.PRODUCER.toString());
+	private static String AUTHOR = PdfName.decodeName(PdfName.AUTHOR.toString());
+	private static String SUBJECT = PdfName.decodeName(PdfName.SUBJECT.toString());
+	private static String CREATOR = PdfName.decodeName(PdfName.CREATOR.toString());
+	private static String MODDATE = PdfName.decodeName(PdfName.MODDATE.toString());
+	private static String CREATIONDATE = PdfName.decodeName(PdfName.CREATIONDATE.toString());
+	private static String KEYWORDS = PdfName.decodeName(PdfName.KEYWORDS.toString());
+	
 	private JPdfSelectionPanel panel;
-    private JFileChooser fileChooser;
+    private JFileChooser fileChooser = null;
     private WorkQueue workQueue = null;
 	
 	public PdfLoader(JPdfSelectionPanel panel){
 		this.panel = panel;
-		fileChooser = new JFileChooser(Configuration.getInstance().getDefaultWorkingDir());
-        fileChooser.setFileFilter(new PdfFilter());
-        fileChooser.setMultiSelectionEnabled(true);
-		//number of threads in workqueue based on the number of selectable documents
-		if(panel.getMaxSelectableFiles() <= 1){
-			workQueue = new WorkQueue(1, 1);
-		}else{
-			workQueue = new WorkQueue(10, 1);			
-//			fileChooser.setAccessory(CommonComponentsFactory.getInstance().createCheckBox(CommonComponentsFactory.DONT_PRESERVER_ORDER_CHECKBOX_TYPE));
-		}
-        
-	}
-
-    
+		workQueue = new WorkQueue();
+	}    
     
     /**
      * adds a file or many files depending on the value of singleSelection
@@ -74,6 +74,7 @@ public class PdfLoader {
     				GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Table full"),
     				JOptionPane.INFORMATION_MESSAGE);
     	}else{
+    		lazyInitFileChooser();
 			if(singleSelection){
 				fileChooser.setMultiSelectionEnabled(false);
 			}else{
@@ -82,7 +83,7 @@ public class PdfLoader {
 			if(!(workQueue.getRunning()>0)){
 		        if (fileChooser.showOpenDialog(panel) == JFileChooser.APPROVE_OPTION){
 		            if(fileChooser.isMultiSelectionEnabled()){
-		            	addFiles(fileChooser.getSelectedFiles(),true);
+		            	addFiles(fileChooser.getSelectedFiles());
 		            }else{
 		            	addFile(fileChooser.getSelectedFile());
 		            }
@@ -99,6 +100,17 @@ public class PdfLoader {
     public void showFileChooserAndAddFiles(){
     	showFileChooserAndAddFiles(false);
     }
+    
+    /**
+     * Lazy JFileChooser initialization
+     */
+    private void lazyInitFileChooser(){
+    	if(fileChooser == null){
+    		fileChooser = new JFileChooser(Configuration.getInstance().getDefaultWorkingDir());
+            fileChooser.setFileFilter(new PdfFilter());
+            fileChooser.setMultiSelectionEnabled(true);
+    	}
+    }
     /**
      * add a file to the selectionTable
      * @param file input file
@@ -107,7 +119,7 @@ public class PdfLoader {
      */
     public synchronized void addFile(File file, String password, String pageSelection){
     	if (file != null){
-    		workQueue.execute(new AddThread(file, password, pageSelection), WorkQueue.SINGLE);
+    		workQueue.execute(new AddThread(file, password, pageSelection));
     	}
     }
     
@@ -135,7 +147,7 @@ public class PdfLoader {
      */
     public synchronized void reloadFile(File file, String password, String pageSelection, int index){
     	if (file != null){
-    		workQueue.execute(new ReloadThread(file, password, pageSelection, index), (file.length()<(LOW_PRIORITY_SIZE))? WorkQueue.HIGH: WorkQueue.LOW);
+    		workQueue.execute(new ReloadThread(file, password, pageSelection, index));
     	}
     }
     
@@ -159,25 +171,16 @@ public class PdfLoader {
     /**
      * adds files to the selectionTable
      * @param files
-     * @param ordered files are added keeping order
      */
     
-    public synchronized void addFiles(File[] files, boolean ordered){
+    public synchronized void addFiles(File[] files){
     	 if (files != null){
          	for (int i=0; i < files.length; i++){
-         		Integer priority = (ordered)?WorkQueue.SINGLE: (files[i].length()<(LOW_PRIORITY_SIZE))? WorkQueue.HIGH: WorkQueue.LOW;
-         		workQueue.execute(new AddThread(files[i]), priority);
+         		workQueue.execute(new AddThread(files[i]));
          	}
          }     
     }
     
-    /**
-     * Add files without keeping order
-     * @param files
-     */
-    public void addFiles(File[] files){
-    	addFiles(files, false);
-    }
     	
     /**
      * adds files to the selectionTable
@@ -186,7 +189,7 @@ public class PdfLoader {
      */
     public void addFiles(List files, boolean ordered){
     	if (files != null && !files.isEmpty()){
-    		addFiles((File[])files.toArray(new File[files.size()]), ordered);
+    		addFiles((File[])files.toArray(new File[files.size()]));
    	 	}     
     }
     
@@ -262,11 +265,31 @@ public class PdfLoader {
             	tableItem.setPassword(password);
             	tableItem.setPageSelection(pageSelection);
                 try{
-                    //fix 03/07 for memory usage
-                    pdfReader = new PdfReader(new RandomAccessFileOrArray(new FileInputStream(fileToAdd)), (password != null)?password.getBytes():null);
+                    //fix 04/11/08 for memory usage
+                    pdfReader = new PdfReader(new RandomAccessFileOrArray(fileToAdd.getAbsolutePath()), (password != null)?password.getBytes():null);                	
                     tableItem.setEncrypted(pdfReader.isEncrypted());
+                    if(tableItem.isEncrypted()){
+                    	tableItem.setPermissions(getPermissionsVerbose(pdfReader.getPermissions()));
+                    	int cMode = pdfReader.getCryptoMode();
+                    	switch (cMode){
+                    	case PdfWriter.STANDARD_ENCRYPTION_40:
+                    		tableItem.setEncryptionAlgorithm(EncryptionUtility.RC4_40);
+                    		break;
+                    	case PdfWriter.STANDARD_ENCRYPTION_128:
+                    		tableItem.setEncryptionAlgorithm(EncryptionUtility.RC4_128);
+                    		break;
+                    	case PdfWriter.ENCRYPTION_AES_128:
+                    		tableItem.setEncryptionAlgorithm(EncryptionUtility.AES_128);
+                    		break;
+                    	default:
+                    		break;                    			
+                    	}
+                    }
                     tableItem.setPagesNumber(Integer.toString(pdfReader.getNumberOfPages()));
+                    tableItem.setFileSize(fileToAdd.length());
                     tableItem.setPdfVersion(pdfReader.getPdfVersion());
+                    tableItem.setSyntaxErrors(pdfReader.isRebuilt());
+                    initTableItemDocumentData(pdfReader, tableItem);
                 }
                 catch (Exception e){
                 	tableItem.setLoadedWithErrors(true);
@@ -280,7 +303,61 @@ public class PdfLoader {
                 }               
             }
             return tableItem;    
-        }              
+        } 
+        
+        /**
+         * It gives a human readable version of the document permissions
+         * @param permissions
+         * @return
+         */
+        private String getPermissionsVerbose(int permissions) {
+        	StringBuffer buf = new StringBuffer();
+        	if ((PdfWriter.ALLOW_PRINTING & permissions) == PdfWriter.ALLOW_PRINTING) buf.append(GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Print"));
+            if ((PdfWriter.ALLOW_MODIFY_CONTENTS & permissions) == PdfWriter.ALLOW_MODIFY_CONTENTS) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Modify"));
+            if ((PdfWriter.ALLOW_COPY & permissions) == PdfWriter.ALLOW_COPY) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Copy or extract"));
+            if ((PdfWriter.ALLOW_MODIFY_ANNOTATIONS & permissions) == PdfWriter.ALLOW_MODIFY_ANNOTATIONS) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Add or modify text annotations"));
+            if ((PdfWriter.ALLOW_FILL_IN & permissions) == PdfWriter.ALLOW_FILL_IN) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Fill form fields"));
+            if ((PdfWriter.ALLOW_SCREENREADERS & permissions) == PdfWriter.ALLOW_SCREENREADERS) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Extract for use by accessibility dev."));
+            if ((PdfWriter.ALLOW_ASSEMBLY & permissions) == PdfWriter.ALLOW_ASSEMBLY) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Manipulate pages and add bookmarks"));
+            if ((PdfWriter.ALLOW_DEGRADED_PRINTING & permissions) == PdfWriter.ALLOW_DEGRADED_PRINTING) buf.append(", "+GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Low quality print"));
+            return buf.toString();
+        }
+        /**
+         * initialization of the document data
+         * @param reader
+         * @param tableItem
+         */
+        private void initTableItemDocumentData(PdfReader reader, PdfSelectionTableItem tableItem){
+        	if(reader!=null && tableItem != null){
+        		HashMap info = reader.getInfo();
+        		if(info!=null && info.size()>0){
+        			for(Iterator entries = info.entrySet().iterator(); entries.hasNext();){
+        				Map.Entry entry = (Map.Entry) entries.next();
+        				if(entry != null){
+        					String key = (String)entry.getKey();
+        					String value = (entry.getValue()!=null)? (String)entry.getValue(): "";
+        					if(key.equals(TITLE)){
+        						tableItem.getDocumentInfo().setTitle(value);
+        					}else if(key.equals(PRODUCER)){
+        						tableItem.getDocumentInfo().setProducer(value);
+        					}else if(key.equals(AUTHOR)){
+        						tableItem.getDocumentInfo().setAuthor(value);
+        					}else if(key.equals(SUBJECT)){
+        						tableItem.getDocumentInfo().setSubject(value);
+        					}else if(key.equals(CREATOR)){
+        						tableItem.getDocumentInfo().setCreator(value);
+        					}else if(key.equals(MODDATE)){
+        						tableItem.getDocumentInfo().setModificationDate(value);
+        					}else if(key.equals(CREATIONDATE)){
+        						tableItem.getDocumentInfo().setCreationDate(value);
+        					}else if(key.equals(KEYWORDS)){
+        						tableItem.getDocumentInfo().setKeywords(value);
+        					}
+        				}
+        			}
+        		}
+        	}
+        }
     }
     
     /**
@@ -333,84 +410,36 @@ public class PdfLoader {
 	   			 log.error(GettextResource.gettext(Configuration.getInstance().getI18nResourceBundle(),"Error: "),e); 
 	   		 }	
 		 }    	
-    }
-    
+    }  
     /**
-     * Work queue used to manage concurrent pdf documents load. It loads concurrently small sized documents and one by one big sized ones  
+     * Work queue used to load documents  
      * @author Andrea Vacondio
      *
      */
     private static class WorkQueue{
-    	
-    	public static final Integer HIGH = new Integer(0);
-    	public static final Integer LOW = new Integer(1);
-    	public static final Integer SINGLE = new Integer(2);
         
-    	private final int highNThreads;
-    	private final int lowNThreads;
-    	
-        private final HighWorker[] highThreads;
-        private final LowWorker[] lowThreads;
         private final SingleWorker singleThread;
-        
-        private final LinkedList highQueue = new LinkedList();
-        private final LinkedList lowQueue = new LinkedList();
+
         private final LinkedList singleQueue = new LinkedList();
-        private int highRunning = 0;
         private int running = 0;
         
         private Object mutex = new Object();
         
-        /**
-         * @param highNThreads number of high priority thread
-         * @param lowNThreads number of low priority thread
-         */
-        public WorkQueue(int highNThreads, int lowNThreads){
-            this.highNThreads = highNThreads;
-            this.lowNThreads = lowNThreads;
-            
-            highThreads = new HighWorker[this.highNThreads];
-            lowThreads = new LowWorker[this.lowNThreads];
+        public WorkQueue(){
             singleThread = new SingleWorker();
             singleThread.start();
-            
-            for (int i=0; i<this.highNThreads; i++) {
-            	highThreads[i] = new HighWorker();
-            	highThreads[i].start();
-            }
-            for (int i=0; i<this.lowNThreads; i++) {
-            	lowThreads[i] = new LowWorker();
-            	lowThreads[i].start();
-            }            
         }
         
         /**
-         * Execute and addThread with the given priority
+         * Execute and addThread
          * @param r
-         * @param priority
          */
-        public void execute(Runnable r, Integer priority) {
-        	synchronized (mutex){
-	           	if(HIGH.equals(priority)){
-	           		highQueue.addLast(r); 
-	           	}else if(SINGLE.equals(priority)){	           		
-	           		singleQueue.addLast(r);
-	           	}else{
-	           		lowQueue.addLast(r);
-	           	}
+        public void execute(Runnable r) {
+        	synchronized (mutex){           		
+	           	singleQueue.addLast(r);
 	           	mutex.notifyAll();
            	}
-        }
-        
-        public synchronized void incHighRunningCounter(){
-        	highRunning++;
-        	incRunningCounter();
-        }
-        
-        public synchronized void deincHighRunningCounter(){
-        	highRunning--;  
-        	deincRunningCounter();
-        }
+        }        
         
         public synchronized void incRunningCounter(){
         	running++;
@@ -422,84 +451,7 @@ public class PdfLoader {
         
         public int getRunning(){
         	return running;
-        }
-        
-        /**
-         * High priority thread
-         * @author Andrea Vacondio
-         *
-         */
-        private class HighWorker extends Thread {
-        	
-        	public void run() {        		            
-        		Runnable r = null;
-        		
-                while (true) {
-                    synchronized(mutex) {
-                         while(highQueue.isEmpty()) {
-                        	 try{
-                        		 mutex.wait();
-                             }
-                             catch (InterruptedException ignored){}
-                         }
-                         r = (Runnable) highQueue.removeFirst();
-                     }
-
-                    if(r != null){
-                    	try {                    	
-                    		 incHighRunningCounter();
-                    		 r.run();                         		
-	                   }catch (RuntimeException e) {
-	                	   log.error(e);
-	                   }
-	                   finally{
-	                	   deincHighRunningCounter();                	  
-	                   }
-                    }                         
-                }
-        	}
-        }
-        
-        /**
-         * Low priority thread
-         * @author Andrea Vacondio
-         *
-         */
-        private class LowWorker extends Thread {
-        	
-        	public void run() {        		            
-        		Runnable r = null;
-        		
-                while (true) {
-                    synchronized(mutex) {
-                         while(lowQueue.isEmpty() || highRunning>0) {
-                        	 try{
-                        		 if(lowQueue.isEmpty()){
-                        			 mutex.wait();
-                        		 }else{
-                        			 mutex.wait(1000);
-                        		 }
-                        		 
-                             }
-                             catch (InterruptedException ignored){}
-                         }
-                         r = (Runnable) lowQueue.removeFirst();
-                     }
-
-                    if(r != null){
-                    	try {
-                    		incRunningCounter();
-                    		r.run();                         		
-                    	}catch (RuntimeException e) {
-                    		log.error(e);
-                    	}
-                    	finally{
-                    		deincRunningCounter();                	  
-                    	}
-               	 	} 
-                }
-        	}
-        }
+        }               
         
         /**
          * Single priority thread
