@@ -14,16 +14,18 @@
  */
 package org.pdfsam.plugin.split.GUI;
 
-import java.awt.Color;
 import java.awt.Component;
 import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.FocusTraversalPolicy;
+import java.awt.GridLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
 import java.util.LinkedList;
 
+import javax.swing.BorderFactory;
 import javax.swing.ButtonGroup;
 import javax.swing.ButtonModel;
 import javax.swing.JButton;
@@ -35,7 +37,6 @@ import javax.swing.JPanel;
 import javax.swing.JRadioButton;
 import javax.swing.JTextField;
 import javax.swing.SpringLayout;
-import javax.swing.border.MatteBorder;
 
 import org.apache.log4j.Logger;
 import org.dom4j.Element;
@@ -44,6 +45,7 @@ import org.pdfsam.console.business.dto.commands.AbstractParsedCommand;
 import org.pdfsam.console.business.dto.commands.MixParsedCommand;
 import org.pdfsam.console.business.dto.commands.SplitParsedCommand;
 import org.pdfsam.guiclient.business.listeners.EnterDoClickListener;
+import org.pdfsam.guiclient.commons.business.SoundPlayer;
 import org.pdfsam.guiclient.commons.business.WorkExecutor;
 import org.pdfsam.guiclient.commons.business.WorkThread;
 import org.pdfsam.guiclient.commons.business.listeners.CompressCheckBoxItemListener;
@@ -61,6 +63,7 @@ import org.pdfsam.guiclient.gui.components.JHelpLabel;
 import org.pdfsam.guiclient.plugins.interfaces.AbstractPlugablePanel;
 import org.pdfsam.guiclient.utils.DialogUtility;
 import org.pdfsam.i18n.GettextResource;
+import org.pdfsam.plugin.split.components.JBLevelCombo;
 import org.pdfsam.plugin.split.components.JSplitRadioButton;
 import org.pdfsam.plugin.split.components.JSplitRadioButtonModel;
 import org.pdfsam.plugin.split.components.JSplitSizeCombo;
@@ -92,6 +95,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
     private Configuration config;
 	private JPdfSelectionPanel selectionPanel = new JPdfSelectionPanel(JPdfSelectionPanel.SINGLE_SELECTABLE_FILE, SimplePdfSelectionTableModel.DEFAULT_SHOWED_COLUMNS_NUMBER);
 	private JSplitSizeCombo splitSizeCombo = new JSplitSizeCombo();
+	private JBLevelCombo bLevelCombo = new JBLevelCombo(selectionPanel);
     
 //file_chooser    
     private JFileChooser browseDestFileChooser = null;
@@ -110,6 +114,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
     private final JSplitRadioButton oddRadio = new JSplitRadioButton(SplitParsedCommand.S_ODD);
     private final JSplitRadioButton thisPageRadio = new JSplitRadioButton(SplitParsedCommand.S_SPLIT);
     private final JSplitRadioButton sizeRadio = new JSplitRadioButton(SplitParsedCommand.S_SIZE);
+    private final JSplitRadioButton bookmarksLevel = new JSplitRadioButton(SplitParsedCommand.S_BLEVEL);
     
     private RadioListener radioListener;
 //radio
@@ -127,17 +132,15 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
     private final JPanel splitOptionsPanel = new JPanel();
     private final JPanel destinationPanel = new JPanel();
     private final JPanel outputOptionsPanel = new JPanel();
-
+    private final JPanel splitTypesPanel = new JPanel();
+    
 //labels    
-    private final JLabel splitOptionsLabel = new JLabel();
-    private final JLabel destFolderLabel = new JLabel();
-    private final JLabel outputOptionsLabel = new JLabel();
     private final JLabel outPrefixLabel = new JLabel();
 	private final JLabel outputVersionLabel = CommonComponentsFactory.getInstance().createLabel(CommonComponentsFactory.PDF_VERSION_LABEL);	
 	
   
     private final String PLUGIN_AUTHOR = "Andrea Vacondio";    
-    private final String PLUGIN_VERSION = "0.4.8";
+    private final String PLUGIN_VERSION = "0.5.2";
     
 /**
  * Constructor
@@ -151,7 +154,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
     private void initialize() {
     	config = Configuration.getInstance();
         setPanelIcon("/images/split.png");
-        setPreferredSize(new Dimension(500,550));
+        setPreferredSize(new Dimension(500,555));
         
 //        
         splitSpringLayout = new SpringLayout();
@@ -161,35 +164,42 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 //SPLIT_SECTION
         optionsPaneLayout = new SpringLayout();
         splitOptionsPanel.setLayout(optionsPaneLayout);
-        splitOptionsPanel.setBorder(new MatteBorder(1, 1, 1, 1, Color.LIGHT_GRAY));
+        
+        splitOptionsPanel.setBorder(BorderFactory.createTitledBorder(GettextResource.gettext(config.getI18nResourceBundle(),"Split options")));
         add(splitOptionsPanel);
 
-        burstRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Burst (split into single pages)"));
-        splitOptionsPanel.add(burstRadio);
-
+        GridLayout splitOptionsLayout = new GridLayout(0,3,5,5);
+        splitTypesPanel.setLayout(splitOptionsLayout);
+        
+        burstRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Burst (split into single pages)"));        
         everyNRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split every \"n\" pages"));
-        splitOptionsPanel.add(everyNRadio);
-        
-        nPagesTextField.setEnabled(false);
-        splitOptionsPanel.add(nPagesTextField);        
-        
         evenRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split even pages"));      
-        splitOptionsPanel.add(evenRadio);
-        
         oddRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split odd pages"));
-        splitOptionsPanel.add(oddRadio);
-        
+        nPagesTextField.setEnabled(false);
         thisPageRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split after these pages"));
-        splitOptionsPanel.add(thisPageRadio);
-        
         sizeRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split at this size"));
-        splitOptionsPanel.add(sizeRadio);
-        
+        bookmarksLevel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split by bookmarks level"));
         thisPageTextField.setEnabled(false);
-        splitOptionsPanel.add(thisPageTextField);
-        
         splitSizeCombo.setEnabled(false);
-        splitOptionsPanel.add(splitSizeCombo);
+        bLevelCombo.setEnabled(false);
+        
+        splitTypesPanel.add(burstRadio);
+        splitTypesPanel.add(thisPageRadio);
+        splitTypesPanel.add(thisPageTextField);
+
+        splitTypesPanel.add(evenRadio);
+        splitTypesPanel.add(everyNRadio);        
+        splitTypesPanel.add(nPagesTextField);        
+                
+        splitTypesPanel.add(oddRadio);               
+        splitTypesPanel.add(sizeRadio);                
+        splitTypesPanel.add(splitSizeCombo);
+        
+        splitTypesPanel.add(new JLabel());               
+        splitTypesPanel.add(bookmarksLevel);                
+        splitTypesPanel.add(bLevelCombo);
+        
+        splitOptionsPanel.add(splitTypesPanel);
         
         String helpText = 
         		"<html><body><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split options")+"</b><ul>" +
@@ -198,18 +208,16 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
         		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split even pages")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document every even page")+".</li>" +
         		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split odd pages")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document every odd page")+".</li>" +
         		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split after these pages")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document after page numbers (num1-num2-num3..)")+".</li>" +
-        		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split at this size")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document in files of the given size (roughly).")+".</li>" +
+        		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split at this size")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document in files of the given size (roughly)")+".</li>" +
+        		"<li><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Split by bookmarks level")+":</b> "+GettextResource.gettext(config.getI18nResourceBundle(),"Split the document at pages referred by bookmarks of the given level")+".</li>" +
         		"</ul></body></html>";
         checksHelpLabel = new JHelpLabel(helpText, true);
         splitOptionsPanel.add(checksHelpLabel);        
 //END_SPLIT_SECTION
-        
-        
-        splitOptionsLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Split options:"));
-        add(splitOptionsLabel);
+
 //RADIO_LISTENERS
         /*This listeners enable or disable text field based on what you select*/
-        radioListener = new RadioListener(this, nPagesTextField, thisPageTextField, splitSizeCombo); 
+        radioListener = new RadioListener(this, nPagesTextField, thisPageTextField, splitSizeCombo, bLevelCombo); 
         burstRadio.setActionCommand(RadioListener.DISABLE_ALL);
         burstRadio.addActionListener(radioListener);
         everyNRadio.setActionCommand(RadioListener.ENABLE_FIRST);
@@ -222,18 +230,16 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
         thisPageRadio.addActionListener(radioListener);
         sizeRadio.setActionCommand(RadioListener.ENABLE_THIRD);
         sizeRadio.addActionListener(radioListener);
+        bookmarksLevel.setActionCommand(RadioListener.ENABLE_FOURTH);
+        bookmarksLevel.addActionListener(radioListener);
 //END_RADIO_LISTENERS 
 //DESTINATION_PANEL
         destinationPanelLayout = new SpringLayout();
         destinationPanel.setLayout(destinationPanelLayout);
-        destinationPanel.setBorder(new MatteBorder(1, 1, 1, 1, Color.LIGHT_GRAY));
+        destinationPanel.setBorder(BorderFactory.createTitledBorder(GettextResource.gettext(config.getI18nResourceBundle(),"Destination folder")));
         add(destinationPanel);
 //END_DESTINATION_PANEL        
 //DESTINATION_RADIOS
-        
-        destFolderLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Destination folder:"));
-        add(destFolderLabel);
-
         sameAsSourceRadio.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Same as source"));
         destinationPanel.add(sameAsSourceRadio);
 
@@ -249,6 +255,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
         splitOptionsRadioGroup.add(oddRadio);
         splitOptionsRadioGroup.add(thisPageRadio);
         splitOptionsRadioGroup.add(sizeRadio);
+        splitOptionsRadioGroup.add(bookmarksLevel);        
         final ButtonGroup outputRadioGroup = new ButtonGroup();
         outputRadioGroup.add(sameAsSourceRadio);
         outputRadioGroup.add(chooseAFolderRadio);  
@@ -271,7 +278,10 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
                     browseDestFileChooser = new JFileChooser(Configuration.getInstance().getDefaultWorkingDir());                    
                     browseDestFileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
             	}
-                File chosenFile = null;                
+                File chosenFile = null;  
+                if(destinationFolderText.getText().length()>0){
+                	browseDestFileChooser.setCurrentDirectory(new File(destinationFolderText.getText()));
+                }
                 if (browseDestFileChooser.showOpenDialog(browseDestButton.getParent()) == JFileChooser.APPROVE_OPTION){
                     chosenFile = browseDestFileChooser.getSelectedFile();
                 }
@@ -301,10 +311,8 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 	    destinationPanel.add(destinationHelpLabel);
 //END_HELP_LABEL_DESTINATION  
 	    
-        outputOptionsLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Output options:"));
-        add(outputOptionsLabel);
 //S_PANEL
-        outputOptionsPanel.setBorder(new MatteBorder(1, 1, 1, 1, Color.LIGHT_GRAY));
+        outputOptionsPanel.setBorder(BorderFactory.createTitledBorder(GettextResource.gettext(config.getI18nResourceBundle(),"Output options")));
         outputPanelLayout = new SpringLayout();
         outputOptionsPanel.setLayout(outputPanelLayout);
         add(outputOptionsPanel);
@@ -312,15 +320,16 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
         outPrefixLabel.setText(GettextResource.gettext(config.getI18nResourceBundle(),"Output file names prefix:"));
         outputOptionsPanel.add(outPrefixLabel);
 
+        outPrefixText.setPreferredSize(new Dimension(180,20));
         outputOptionsPanel.add(outPrefixText);
 //END_S_PANEL
 //HELP_LABEL_PREFIX       
         String helpTextPrefix = 
     		"<html><body><b>"+GettextResource.gettext(config.getI18nResourceBundle(),"Output files prefix")+"</b>" +
-    		"<p> "+GettextResource.gettext(config.getI18nResourceBundle(),"If it contains \"[CURRENTPAGE]\" or \"[TIMESTAMP]\" it performs variable substitution.")+"</p>"+
+    		"<p> "+GettextResource.gettext(config.getI18nResourceBundle(),"If it contains \"[CURRENTPAGE]\", \"[TIMESTAMP]\", \"[FILENUMBER]\" or \"[BOOKMARK_NAME]\" it performs variable substitution.")+"</p>"+
     		"<p> "+GettextResource.gettext(config.getI18nResourceBundle(),"Ex. prefix_[BASENAME]_[CURRENTPAGE] generates prefix_FileName_005.pdf.")+"</p>"+
-    		"<br><p> "+GettextResource.gettext(config.getI18nResourceBundle(),"If it doesn't contain \"[CURRENTPAGE]\" or \"[TIMESTAMP]\" it generates oldstyle output file names.")+"</p>"+
-    		"<br><p> "+GettextResource.gettext(config.getI18nResourceBundle(),"Available variables: [CURRENTPAGE], [TIMESTAMP], [BASENAME].")+"</p>"+
+    		"<br><p> "+GettextResource.gettext(config.getI18nResourceBundle(),"If it doesn't contain \"[CURRENTPAGE]\", \"[TIMESTAMP]\" or \"[FILENUMBER]\" it generates oldstyle output file names.")+"</p>"+
+    		"<br><p> "+GettextResource.gettext(config.getI18nResourceBundle(),"Available variables")+": [CURRENTPAGE], [TIMESTAMP], [BASENAME], [FILENUMBER], [BOOKMARK_NAME].</p>"+
     		"</body></html>";
 	    prefixHelpLabel = new JHelpLabel(helpTextPrefix, true);
 	    outputOptionsPanel.add(prefixHelpLabel);
@@ -356,8 +365,8 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 	                        args.add("-"+SplitParsedCommand.N_ARG);
 	                        args.add(thisPageTextField.getText());                        
 	                    }else if (splitType.equals(SplitParsedCommand.S_NSPLIT)){
-	                            args.add("-"+SplitParsedCommand.N_ARG);
-	                            args.add(nPagesTextField.getText());                        
+	                        args.add("-"+SplitParsedCommand.N_ARG);
+	                        args.add(nPagesTextField.getText());                        
 	                    }else if (splitType.equals(SplitParsedCommand.S_SIZE)){
 	                        args.add("-"+SplitParsedCommand.B_ARG);
 	                        if(splitSizeCombo.isSelectedItem() && splitSizeCombo.isValidSelectedItem()){
@@ -365,7 +374,10 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 	                        }else{
 	                        	throw new Exception(GettextResource.gettext(config.getI18nResourceBundle(),"Invalid split size"));
 	                        }
-	                    }                      
+	                    } else if (splitType.equals(SplitParsedCommand.S_BLEVEL)){
+	                    	 args.add("-"+SplitParsedCommand.BL_ARG);
+	                    	 args.add((String)bLevelCombo.getSelectedItem()); 
+	                    }
 	                                        
 	                    args.add("-"+SplitParsedCommand.O_ARG);
 	                    //check radio for output options
@@ -421,10 +433,13 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 					}
                 }catch(Exception ex){    
                 	log.error(GettextResource.gettext(config.getI18nResourceBundle(),"Error: "), ex);
+                	SoundPlayer.getInstance().playErrorSound();
                 }      
             }
         });
         runButton.setToolTipText(GettextResource.gettext(config.getI18nResourceBundle(),"Split selected file"));
+        runButton.setMargin(new Insets(5, 5, 5, 5));
+        runButton.setSize(new Dimension(88,25));
         add(runButton);
 //END_RUN_BUTTON
         
@@ -499,6 +514,11 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 				Element splitSize = ((Element)arg0).addElement("splitsize");
 				splitSize.addAttribute("value", splitSizeCombo.getSelectedItem().toString());			
 
+				Element bookLevel = ((Element)arg0).addElement("bookmarkslevel");
+				if(bLevelCombo.getSelectedItem() != null){
+					bookLevel.addAttribute("value", bLevelCombo.getSelectedItem().toString());			
+				}
+				
 				Element fileDestination = ((Element)arg0).addElement("destination");
 				fileDestination.addAttribute("value", destinationFolderText.getText());			
 				
@@ -544,6 +564,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 					else if(splitOption.getText().equals(oddRadio.getSplitCommand()))  oddRadio.doClick();
 					else if(splitOption.getText().equals(thisPageRadio.getSplitCommand()))  thisPageRadio.doClick();
 					else if(splitOption.getText().equals(sizeRadio.getSplitCommand()))  sizeRadio.doClick();
+					else if(splitOption.getText().equals(bookmarksLevel.getSplitCommand()))  bookmarksLevel.doClick();					
 				}
 				Node splitNpages = (Node) arg0.selectSingleNode("npages/@value");
 				if (splitNpages != null){
@@ -560,6 +581,11 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 					splitSizeCombo.setSelectedItem(splitSize.getText());
 				}
 				
+				Node bookLevel = (Node) arg0.selectSingleNode("bookmarkslevel/@value");
+				if (bookLevel != null){
+					bLevelCombo.setSelectedItem(bookLevel.getText());
+				}
+				
 				Node fileDestination = (Node) arg0.selectSingleNode("destination/@value");
 				if (fileDestination != null && fileDestination.getText().length()>0){
 					destinationFolderText.setText(fileDestination.getText());
@@ -607,29 +633,22 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
      */
     private void setLayout(){
     	splitSpringLayout.putConstraint(SpringLayout.SOUTH, selectionPanel, 115, SpringLayout.NORTH, this);
-		splitSpringLayout.putConstraint(SpringLayout.EAST, selectionPanel, -5, SpringLayout.EAST, this);
-		splitSpringLayout.putConstraint(SpringLayout.NORTH, selectionPanel, 5, SpringLayout.NORTH, this);
-		splitSpringLayout.putConstraint(SpringLayout.WEST, selectionPanel, 5, SpringLayout.WEST, this);
+		splitSpringLayout.putConstraint(SpringLayout.EAST, selectionPanel, 0, SpringLayout.EAST, this);
+		splitSpringLayout.putConstraint(SpringLayout.NORTH, selectionPanel, 0, SpringLayout.NORTH, this);
+		splitSpringLayout.putConstraint(SpringLayout.WEST, selectionPanel, 0, SpringLayout.WEST, this);
 //      LAYOUT
-        splitSpringLayout.putConstraint(SpringLayout.SOUTH, splitOptionsPanel, 103, SpringLayout.NORTH, splitOptionsPanel);
-        splitSpringLayout.putConstraint(SpringLayout.EAST, splitOptionsPanel, -5, SpringLayout.EAST, this);
+        splitSpringLayout.putConstraint(SpringLayout.SOUTH, splitOptionsPanel, 145, SpringLayout.NORTH, splitOptionsPanel);
+        splitSpringLayout.putConstraint(SpringLayout.EAST, splitOptionsPanel, 0, SpringLayout.EAST, this);
         splitSpringLayout.putConstraint(SpringLayout.NORTH, splitOptionsPanel, 20, SpringLayout.SOUTH, selectionPanel);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, splitOptionsPanel, 0, SpringLayout.WEST, selectionPanel);
+        splitSpringLayout.putConstraint(SpringLayout.WEST, splitOptionsPanel, 0, SpringLayout.WEST, selectionPanel);       
         
-        splitSpringLayout.putConstraint(SpringLayout.SOUTH, splitOptionsLabel, 0, SpringLayout.NORTH, splitOptionsPanel);
-        splitSpringLayout.putConstraint(SpringLayout.NORTH, splitOptionsLabel, 5, SpringLayout.SOUTH, selectionPanel);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, splitOptionsLabel, 0, SpringLayout.WEST, selectionPanel);
-        
-        splitSpringLayout.putConstraint(SpringLayout.NORTH, destFolderLabel, 5, SpringLayout.SOUTH, splitOptionsPanel);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, destFolderLabel, 0, SpringLayout.WEST, splitOptionsPanel);
-        
-        splitSpringLayout.putConstraint(SpringLayout.SOUTH, destinationPanel, 130, SpringLayout.NORTH, destinationPanel);
+        splitSpringLayout.putConstraint(SpringLayout.SOUTH, destinationPanel, 160, SpringLayout.NORTH, destinationPanel);
         splitSpringLayout.putConstraint(SpringLayout.EAST, destinationPanel, 0, SpringLayout.EAST, splitOptionsPanel);
-        splitSpringLayout.putConstraint(SpringLayout.NORTH, destinationPanel, 20, SpringLayout.SOUTH, splitOptionsPanel);
+        splitSpringLayout.putConstraint(SpringLayout.NORTH, destinationPanel, 10, SpringLayout.SOUTH, splitOptionsPanel);
         splitSpringLayout.putConstraint(SpringLayout.WEST, destinationPanel, 0, SpringLayout.WEST, splitOptionsPanel);
         
         destinationPanelLayout.putConstraint(SpringLayout.SOUTH, sameAsSourceRadio, 25, SpringLayout.NORTH, sameAsSourceRadio);
-        destinationPanelLayout.putConstraint(SpringLayout.NORTH, sameAsSourceRadio, 1, SpringLayout.NORTH, destinationPanel);
+        destinationPanelLayout.putConstraint(SpringLayout.NORTH, sameAsSourceRadio, 0, SpringLayout.NORTH, destinationPanel);
         destinationPanelLayout.putConstraint(SpringLayout.WEST, sameAsSourceRadio, 10, SpringLayout.WEST, destinationPanel);        
         destinationPanelLayout.putConstraint(SpringLayout.SOUTH, chooseAFolderRadio, 0, SpringLayout.SOUTH, sameAsSourceRadio);
         destinationPanelLayout.putConstraint(SpringLayout.NORTH, chooseAFolderRadio, 0, SpringLayout.NORTH, sameAsSourceRadio);
@@ -663,64 +682,29 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
         
         destinationPanelLayout.putConstraint(SpringLayout.SOUTH, destinationHelpLabel, -1, SpringLayout.SOUTH, destinationPanel);
         destinationPanelLayout.putConstraint(SpringLayout.EAST, destinationHelpLabel, -1, SpringLayout.EAST, destinationPanel);
-        
-        splitSpringLayout.putConstraint(SpringLayout.EAST, outputOptionsLabel, 0, SpringLayout.EAST, destinationPanel);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, outputOptionsLabel, 0, SpringLayout.WEST, destinationPanel);
-        splitSpringLayout.putConstraint(SpringLayout.NORTH, outputOptionsLabel, 5, SpringLayout.SOUTH, destinationPanel);
+
 		
-        splitSpringLayout.putConstraint(SpringLayout.SOUTH, outputOptionsPanel, 48, SpringLayout.NORTH, outputOptionsPanel);
+        splitSpringLayout.putConstraint(SpringLayout.SOUTH, outputOptionsPanel, 55, SpringLayout.NORTH, outputOptionsPanel);
         splitSpringLayout.putConstraint(SpringLayout.EAST, outputOptionsPanel, 0, SpringLayout.EAST, destinationPanel);
-        splitSpringLayout.putConstraint(SpringLayout.NORTH, outputOptionsPanel, 0, SpringLayout.SOUTH, outputOptionsLabel);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, outputOptionsPanel, 0, SpringLayout.WEST, outputOptionsLabel);
-        outputPanelLayout.putConstraint(SpringLayout.SOUTH, outPrefixLabel, 25, SpringLayout.NORTH, outputOptionsPanel);
-        outputPanelLayout.putConstraint(SpringLayout.NORTH, outPrefixLabel, 5, SpringLayout.NORTH, outputOptionsPanel);
+        splitSpringLayout.putConstraint(SpringLayout.NORTH, outputOptionsPanel, 10, SpringLayout.SOUTH, destinationPanel);
+        splitSpringLayout.putConstraint(SpringLayout.WEST, outputOptionsPanel, 0, SpringLayout.WEST, destinationPanel);
+        outputPanelLayout.putConstraint(SpringLayout.SOUTH, outPrefixLabel, 20, SpringLayout.NORTH, outputOptionsPanel);
+        outputPanelLayout.putConstraint(SpringLayout.NORTH, outPrefixLabel, 0, SpringLayout.NORTH, outputOptionsPanel);
         outputPanelLayout.putConstraint(SpringLayout.WEST, outPrefixLabel, 5, SpringLayout.WEST, outputOptionsPanel);
-        outputPanelLayout.putConstraint(SpringLayout.EAST, outPrefixText, -10, SpringLayout.EAST, outputOptionsPanel);
         outputPanelLayout.putConstraint(SpringLayout.SOUTH, outPrefixText, 0, SpringLayout.SOUTH, outPrefixLabel);
-        outputPanelLayout.putConstraint(SpringLayout.NORTH, outPrefixText, 0, SpringLayout.NORTH, outPrefixLabel);
-        outputPanelLayout.putConstraint(SpringLayout.WEST, outPrefixText, 15, SpringLayout.EAST, outPrefixLabel);
+        outputPanelLayout.putConstraint(SpringLayout.WEST, outPrefixText, 10, SpringLayout.EAST, outPrefixLabel);
 
         outputPanelLayout.putConstraint(SpringLayout.SOUTH, prefixHelpLabel, -1, SpringLayout.SOUTH, outputOptionsPanel);
         outputPanelLayout.putConstraint(SpringLayout.EAST, prefixHelpLabel, -1, SpringLayout.EAST, outputOptionsPanel);
         
-        splitSpringLayout.putConstraint(SpringLayout.SOUTH, runButton, 25, SpringLayout.NORTH, runButton);
-        splitSpringLayout.putConstraint(SpringLayout.EAST, runButton, -10, SpringLayout.EAST, this);
-        splitSpringLayout.putConstraint(SpringLayout.WEST, runButton, -88, SpringLayout.EAST, runButton);
+        splitSpringLayout.putConstraint(SpringLayout.EAST, runButton, -11, SpringLayout.EAST, this);
         splitSpringLayout.putConstraint(SpringLayout.NORTH, runButton, 10, SpringLayout.SOUTH, outputOptionsPanel);
 
 
 //      RADIO_LAYOUT
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, burstRadio, 10, SpringLayout.NORTH, splitOptionsPanel);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, burstRadio, 10, SpringLayout.WEST, splitOptionsPanel);
-                
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, evenRadio, 0, SpringLayout.WEST, burstRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, evenRadio, 2, SpringLayout.SOUTH, burstRadio);
-        
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, oddRadio, 0, SpringLayout.WEST, evenRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, oddRadio, 2, SpringLayout.SOUTH, evenRadio);
-        
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, thisPageRadio, 0, SpringLayout.NORTH, burstRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, thisPageRadio, 2, SpringLayout.EAST, burstRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.SOUTH, thisPageTextField, 17, SpringLayout.NORTH, thisPageTextField);
-        optionsPaneLayout.putConstraint(SpringLayout.EAST, thisPageTextField, 75, SpringLayout.EAST, thisPageRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, thisPageTextField, 0, SpringLayout.NORTH, thisPageRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, thisPageTextField, 5, SpringLayout.EAST, thisPageRadio);
-        
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, everyNRadio, 2, SpringLayout.SOUTH, thisPageRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, everyNRadio, 2, SpringLayout.EAST, evenRadio);
-        
-        optionsPaneLayout.putConstraint(SpringLayout.SOUTH, nPagesTextField, 17, SpringLayout.NORTH, everyNRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.EAST, nPagesTextField, 45, SpringLayout.EAST, everyNRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, nPagesTextField, 0, SpringLayout.NORTH, everyNRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, nPagesTextField, 5, SpringLayout.EAST, everyNRadio);
-
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, sizeRadio, 2, SpringLayout.EAST, oddRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, sizeRadio, 2, SpringLayout.SOUTH, everyNRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.SOUTH, splitSizeCombo, 17, SpringLayout.NORTH, splitSizeCombo);
-        optionsPaneLayout.putConstraint(SpringLayout.EAST, splitSizeCombo, 100, SpringLayout.EAST, sizeRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.NORTH, splitSizeCombo, 0, SpringLayout.NORTH, sizeRadio);
-        optionsPaneLayout.putConstraint(SpringLayout.WEST, splitSizeCombo, 5, SpringLayout.EAST, sizeRadio);
-        
+        optionsPaneLayout.putConstraint(SpringLayout.NORTH, splitTypesPanel, 0, SpringLayout.NORTH, splitOptionsPanel);
+        optionsPaneLayout.putConstraint(SpringLayout.WEST, splitTypesPanel, 10, SpringLayout.WEST, splitOptionsPanel);
+                 
         optionsPaneLayout.putConstraint(SpringLayout.SOUTH, checksHelpLabel, -1, SpringLayout.SOUTH, splitOptionsPanel);
         optionsPaneLayout.putConstraint(SpringLayout.EAST, checksHelpLabel, -1, SpringLayout.EAST, splitOptionsPanel);         
     }
@@ -787,13 +771,30 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
             else if (aComponent.equals(sizeRadio)){
                 if (splitSizeCombo.isEnabled()){
                     return splitSizeCombo;
+                }else{
+                    return bookmarksLevel;
+                }
+            }
+            else if (aComponent.equals(splitSizeCombo) || aComponent.getParent().equals(splitSizeCombo)){
+                return bookmarksLevel;
+            }
+            else if (aComponent.equals(bookmarksLevel)){
+                if (bLevelCombo.isEnabled()){
+                    return bLevelCombo.getLevelCombo();
                 }else{
                     return sameAsSourceRadio;
                 }
             }
-            else if (aComponent.equals(splitSizeCombo) || aComponent.equals(splitSizeCombo.getEditor())){
+            else if (aComponent.equals(bLevelCombo.getLevelCombo()) || aComponent.getParent().equals(bLevelCombo.getLevelCombo())){
+            	if (bLevelCombo.getFillCombo().isEnabled()){
+                    return bLevelCombo.getFillCombo();
+                }else{
+                    return sameAsSourceRadio;
+                }
+            }
+            else if (aComponent.equals(bLevelCombo.getFillCombo())){
                 return sameAsSourceRadio;
-            }        
+            }
             else if (aComponent.equals(sameAsSourceRadio)){
                 return chooseAFolderRadio;
             }
@@ -862,13 +863,30 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
                 return sameAsSourceRadio;
             }        
             else if (aComponent.equals(sameAsSourceRadio)){
+                if (bLevelCombo.isEnabled()){
+                	if(bLevelCombo.getFillCombo().isEnabled()){
+                		return bLevelCombo.getFillCombo();
+                	}else{
+                		return bLevelCombo.getLevelCombo();
+                	}                    
+                }else{
+                    return bookmarksLevel;
+                }
+            }
+            else if (aComponent.equals(bLevelCombo.getLevelCombo()) || aComponent.getParent().equals(bLevelCombo.getLevelCombo())){
+                return bookmarksLevel;
+            }
+            else if (aComponent.equals(bLevelCombo.getFillCombo())){
+                return bLevelCombo.getLevelCombo();
+            }  
+            else if (aComponent.equals(bookmarksLevel)){
                 if (splitSizeCombo.isEnabled()){
                     return splitSizeCombo;
                 }else{
                     return sizeRadio;
                 }
             }
-            else if (aComponent.equals(splitSizeCombo) || aComponent.equals(splitSizeCombo.getEditor())){
+            else if (aComponent.equals(splitSizeCombo) || aComponent.getParent().equals(splitSizeCombo)){
                 return sizeRadio;
             }
             else if (aComponent.equals(sizeRadio)){
@@ -931,6 +949,7 @@ public class SplitMainGUI  extends AbstractPlugablePanel{
 		thisPageTextField.setText("");
 	    nPagesTextField.setText("");
 	    outPrefixText.setText("pdfsam_");
+	    bLevelCombo.resetComponent();
 	    ButtonModel bmodel=splitOptionsRadioGroup.getSelection();
 	    if(bmodel != null){
 	    	bmodel.setSelected(false);
